@@ -1,4 +1,4 @@
-# Copyright 2020 Q-CTRL Pty Ltd & Q-CTRL Inc. All rights reserved.
+# Copyright 2021 Q-CTRL. All rights reserved.
 #
 # Licensed under the Q-CTRL Terms of service (the "License"). Unauthorized
 # copying or use of this file, via any medium, is strictly prohibited.
@@ -93,7 +93,7 @@ def build_namespaces(qc: "Qctrl"):  # pylint:disable=invalid-name
 
     for name, field in mutation_type.fields.items():
         if _is_valid_function_mutation(name):
-            func = build_function(qc.gql_api, qc.gql_env, name, field)
+            func = build_function(qc.gql_env, name, field)
             function_namespace.extend_functions(func)
 
     type_namespace.add_registry(qc.gql_env.type_registry)
