@@ -6,12 +6,11 @@ from typing import (
     Optional,
 )
 
-from gql import Client
-from graphql import DocumentNode
 from qctrlcommons.exceptions import QctrlGqlException
 from qctrlcommons.serializers import DataTypeDecoder
 from tqdm.auto import tqdm
 
+from ..queries import RefreshActionQuery
 from .result_mixin import ResultMixin
 from .utils import _get_function_name
 
@@ -23,12 +22,10 @@ class AsyncResult:
 
     def __init__(
         self,
-        gql_client: Client,
         action: ResultMixin,
         progress_bar: tqdm,
-        refresh_query: DocumentNode,
+        refresh_query: RefreshActionQuery,
     ):
-        self.gql_client = gql_client
         self.action = action
         self.progress = progress_bar
         self.refresh_query = refresh_query
@@ -64,7 +61,7 @@ class AsyncResult:
         QctrlGqlException
             if there are some errors in `coreAction` query.
         """
-        query_result: Dict = self.gql_client.execute(self.refresh_query)
+        query_result: Dict = self.refresh_query(self.action.action_id)
 
         if query_result["coreAction"].get("errors"):
             raise QctrlGqlException(
