@@ -1,4 +1,4 @@
-# Copyright 2020 Q-CTRL Pty Ltd & Q-CTRL Inc. All rights reserved.
+# Copyright 2021 Q-CTRL. All rights reserved.
 #
 # Licensed under the Q-CTRL Terms of service (the "License"). Unauthorized
 # copying or use of this file, via any medium, is strictly prohibited.
@@ -19,17 +19,17 @@ from typing import (
 )
 
 import inflection
-from gql import (
-    Client,
-    gql,
-)
+from gql import Client
 from graphql import (
-    DocumentNode,
     GraphQLNonNull,
     GraphQLType,
 )
 from tqdm.auto import tqdm
 
+from ..queries import (
+    RefreshActionQuery,
+    StartActionQuery,
+)
 from .async_result import AsyncResult
 from .custom_handlers import (
     ComplexArrayEntryHandler,
@@ -64,11 +64,6 @@ class QctrlGraphQLEnvironment(GraphQLEnvironment):
         "action": r"{ modelId name status errors { exception } progress }"
     }
 
-    refresh_parameters = (
-        "{ action { modelId name status errors { exception } progress result } "
-        "errors { fields message } }"
-    )
-
     def __init__(
         self,
         gql_client: Client,
@@ -101,28 +96,29 @@ class QctrlGraphQLEnvironment(GraphQLEnvironment):
         input_type: GraphQLType,
         result_type: GraphQLType,
         data: Any,
-    ) -> DocumentNode:
-        """Returns the corresponding GraphQL mutation query."""
+    ) -> StartActionQuery:
+        """Returns the corresponding StartActionQuery object."""
         payload = self.format_payload(input_type, data)
         selection = self.get_selection(result_type, self._action_selection_override)
 
-        query = (
-            f"mutation startAction {{{mutation_name}(input: {payload}) {selection}}}"
+        query = StartActionQuery(
+            self._gql_client,
+            mutation_name=mutation_name,
+            payload=payload,
+            selection=selection,
         )
-        LOGGER.debug("query:%s", query)
-        return gql(query)
+
+        return query
 
     def wait_for_completion(
-        self, field_type: GraphQLType, obj: Any, refresh_query: DocumentNode
+        self, field_type: GraphQLType, obj: Any, refresh_query: RefreshActionQuery
     ):
         """Waits until the corresponding action is completed on the server."""
         _wait = Wait()
 
         with tqdm(total=100, leave=False) as progress_bar:
             _total = 0
-            async_result = AsyncResult(
-                self._gql_client, obj, progress_bar, refresh_query
-            )
+            async_result = AsyncResult(obj, progress_bar, refresh_query)
 
             while not obj.is_completed:
                 progress = int(obj.progress * 100) - _total
@@ -151,38 +147,15 @@ class QctrlGraphQLEnvironment(GraphQLEnvironment):
             "Action %s finished with status: %s", str(obj.action_id), obj.status
         )
 
-    def build_refresh_query(
-        self, field_type: GraphQLType, action_id: int
-    ) -> DocumentNode:
-        """Returns a GraphQL query to select data for
+    def build_refresh_query(self, field_type: GraphQLType) -> RefreshActionQuery:
+        """Returns a RefreshActionQuery object for
         refreshing an object populated with response data.
         """
 
         if isinstance(field_type, GraphQLNonNull):
             field_type = field_type.of_type
 
-        selection = self.refresh_parameters
-        query = (
-            """
-        query refreshAction {{
-            coreAction(modelId: "{action_id}") {{
-                coreAction {{
-                    ... on {field_type} {selection}
-                }}
-                errors {{
-                    message
-                    fields
-                }}
-            }}
-        }}"""
-        ).format(
-            action_id=action_id,
-            field_type=field_type.name,
-            selection=selection,
-        )
-
-        LOGGER.debug("query:%s", query)
-        return gql(query)
+        return RefreshActionQuery(self._gql_client, field_type=field_type.name)
 
 
 def create_environment(gql_client: Client) -> QctrlGraphQLEnvironment:
