@@ -1,4 +1,4 @@
-# Copyright 2020 Q-CTRL Pty Ltd & Q-CTRL Inc. All rights reserved.
+# Copyright 2021 Q-CTRL. All rights reserved.
 #
 # Licensed under the Q-CTRL Terms of service (the "License"). Unauthorized
 # copying or use of this file, via any medium, is strictly prohibited.
@@ -18,7 +18,6 @@ from typing import (
 )
 
 import forge
-from gql import Client
 from gql.transport.exceptions import TransportQueryError
 from graphql import (
     GraphQLArgument,
@@ -49,7 +48,6 @@ LOGGER = logging.getLogger(__name__)
 
 
 def build_function(
-    client: Client,
     env: QctrlGraphQLEnvironment,
     mutation_name: str,
     mutation_field: GraphQLField,
@@ -58,9 +56,6 @@ def build_function(
 
     Parameters
     ----------
-    client: Client
-        The GraphQL client object.
-
     env: QctrlGraphQLEnvironment
         The custom GraphQL environment object.
 
@@ -79,7 +74,6 @@ def build_function(
     input_type = _get_mutation_input_type(mutation_field)
 
     def func(**kwargs):
-        disable_result_cache = kwargs.pop("disable_result_cache", False)
         query = env.build_mutation_query(
             mutation_name,
             input_type,
@@ -90,7 +84,7 @@ def build_function(
         LOGGER.debug("query:%s", query)
 
         try:
-            response = client.execute(query, disable_result_cache=disable_result_cache)
+            response = query()
         except TransportQueryError as exc:
             LOGGER.debug("query execution failed: %s", exc)
             error_dict = get_gql_error_dict(exc)
@@ -110,7 +104,7 @@ def build_function(
         LOGGER.info(
             "Remote function %s called - Action ID: %s", result.name, result.action_id
         )
-        refresh_query = env.build_refresh_query(mutation_field.type, result.action_id)
+        refresh_query = env.build_refresh_query(mutation_field.type)
         env.wait_for_completion(mutation_field.type, result, refresh_query)
         return result
 
