@@ -1,4 +1,4 @@
-# Copyright 2020 Q-CTRL Pty Ltd & Q-CTRL Inc. All rights reserved.
+# Copyright 2021 Q-CTRL. All rights reserved.
 #
 # Licensed under the Q-CTRL Terms of service (the "License"). Unauthorized
 # copying or use of this file, via any medium, is strictly prohibited.
@@ -14,7 +14,10 @@
 import logging
 import os
 from threading import Thread
-from typing import Dict
+from typing import (
+    Dict,
+    Union,
+)
 
 import pythonflow as pf
 import tenacity
@@ -38,9 +41,12 @@ from .builders import (
 from .constants import DEFAULT_API_ROOT
 from .queries import (
     ActivityMonitorQuery,
-    GetResultQuery,
+    GetMutationNameQuery,
+)
+from .utils import (
+    _check_qctrl_latest_version,
+    _get_mutation_result_type,
 )
-from .utils import _check_qctrl_latest_version
 
 LOGGER = logging.getLogger(__name__)
 
@@ -199,7 +205,9 @@ class Qctrl:
             )
         )
 
-    def get_result(self, action_id: str) -> "qctrl.dynamic.types.CoreActionResult":
+    def get_result(
+        self, action_id: Union[str, int]
+    ) -> "qctrl.dynamic.types.CoreActionResult":
         """This function is used to return the results of a previously run function.
         You will be able to get the id of your action from the activity monitor.
 
@@ -213,8 +221,21 @@ class Qctrl:
         qctrl.dynamic.types.CoreActionResult
             an instance of a class derived from a CoreActionResult.
         """
-        get_result = GetResultQuery(self.gql_api)
-        return get_result(self.gql_env, action_id)
+        action_id = str(action_id)
+
+        query = GetMutationNameQuery(self.gql_api)
+        mutation_name = query(action_id)
+
+        field_type = _get_mutation_result_type(self.gql_api.schema, mutation_name)
+
+        refresh_query = self.gql_env.build_refresh_query(field_type)
+        response = refresh_query(action_id)
+
+        result = self.gql_env.load_data(
+            field_type, response["coreAction"]["coreAction"]
+        )
+        self.gql_env.wait_for_completion(field_type, result, refresh_query)
+        return result
 
     def _run_gql_query(self, query: str, variable_values: Dict = None) -> Dict:
         """
