@@ -1,4 +1,4 @@
-# Copyright 2020 Q-CTRL Pty Ltd & Q-CTRL Inc. All rights reserved.
+# Copyright 2021 Q-CTRL. All rights reserved.
 #
 # Licensed under the Q-CTRL Terms of service (the "License"). Unauthorized
 # copying or use of this file, via any medium, is strictly prohibited.
@@ -17,6 +17,8 @@ from .get_environment import (
     GetQueueInfoQuery,
     GetWorkerInfoQuery,
 )
-from .get_result import GetResultQuery
+from .get_mutation_name import GetMutationNameQuery
 from .me import MeQuery
+from .refresh_action import RefreshActionQuery
 from .refresh_token import RefreshTokenQuery
+from .start_action import StartActionQuery
