@@ -1,4 +1,4 @@
-# Copyright 2020 Q-CTRL Pty Ltd & Q-CTRL Inc. All rights reserved.
+# Copyright 2021 Q-CTRL. All rights reserved.
 #
 # Licensed under the Q-CTRL Terms of service (the "License"). Unauthorized
 # copying or use of this file, via any medium, is strictly prohibited.
@@ -16,10 +16,10 @@ from typing import Union
 
 from gql import gql
 
-from qctrl.queries.base import BaseQuery
+from qctrl.queries.base import StaticQuery
 
 
-class ActionExportQuery(BaseQuery):
+class ActionExportQuery(StaticQuery):
     """
     Extracts data from the actions table.
     """
