@@ -1,4 +1,4 @@
-# Copyright 2020 Q-CTRL Pty Ltd & Q-CTRL Inc. All rights reserved.
+# Copyright 2021 Q-CTRL. All rights reserved.
 #
 # Licensed under the Q-CTRL Terms of service (the "License"). Unauthorized
 # copying or use of this file, via any medium, is strictly prohibited.
@@ -20,10 +20,10 @@ from dateutil.parser import isoparse
 from gql import gql
 from qctrlcommons.exceptions import QctrlException
 
-from .base import BaseQuery
+from .base import StaticQuery
 
 
-class ActivityMonitorQuery(BaseQuery):
+class ActivityMonitorQuery(StaticQuery):
     """Retrieves recent activity."""
 
     query = gql(
