@@ -1,4 +1,4 @@
-# Copyright 2020 Q-CTRL Pty Ltd & Q-CTRL Inc. All rights reserved.
+# Copyright 2021 Q-CTRL. All rights reserved.
 #
 # Licensed under the Q-CTRL Terms of service (the "License"). Unauthorized
 # copying or use of this file, via any medium, is strictly prohibited.
@@ -18,10 +18,10 @@ from typing import (
 
 from gql import gql
 
-from .base import BaseQuery
+from .base import StaticQuery
 
 
-class EnvironmentQuery(BaseQuery):  # pylint:disable=too-few-public-methods
+class EnvironmentQuery(StaticQuery):  # pylint:disable=too-few-public-methods
     """Retrieves info about the current environment."""
 
     query = gql(
