@@ -1,4 +1,4 @@
-# Copyright 2020 Q-CTRL Pty Ltd & Q-CTRL Inc. All rights reserved.
+# Copyright 2021 Q-CTRL. All rights reserved.
 #
 # Licensed under the Q-CTRL Terms of service (the "License"). Unauthorized
 # copying or use of this file, via any medium, is strictly prohibited.
@@ -13,10 +13,10 @@
 # pylint:disable=missing-module-docstring
 from gql import gql
 
-from .base import BaseQuery
+from .base import StaticQuery
 
 
-class MeQuery(BaseQuery):  # pylint:disable=too-few-public-methods
+class MeQuery(StaticQuery):  # pylint:disable=too-few-public-methods
     """Retrieves info for the current user."""
 
     query = gql(
